pigz version 2.8
diff --git a/README b/README
index 31f25dd..827b686 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-pigz 2.7 (15 Jan 2022) by Mark Adler
+pigz 2.8 (19 Aug 2022) by Mark Adler
 
 pigz, which stands for Parallel Implementation of GZip, is a fully functional
 replacement for gzip that exploits multiple processors and multiple cores to
diff --git a/pigz.1 b/pigz.1
index c4352e1..030adcf 100644
--- a/pigz.1
+++ b/pigz.1
@@ -1,4 +1,4 @@
-.TH PIGZ 1 "January 15, 2022"
+.TH PIGZ 1 "August 19, 2023"
 .SH NAME
 pigz, unpigz \- compress or expand files
 .SH SYNOPSIS
@@ -178,7 +178,7 @@
 .B -M --time
 Store or restore the modification time. -nM will store or restore the
 modification time, but not the name. Note that the order of the options is
-important.
+important. Modification times are stored only for regular files, not pipes.
 .TP
 .B -n --no-name
 Do not store or restore the file name or the modification time. This is the
@@ -242,4 +242,4 @@
 warranty.  In no event will the author be held liable for any damages
 arising from the use of this software.
 .PP
-Copyright (C) 2007-2022 Mark Adler <madler@alumni.caltech.edu>
+Copyright (C) 2007-2023 Mark Adler <madler@alumni.caltech.edu>
diff --git a/pigz.pdf b/pigz.pdf
index 8df3112..ff460ba 100644
--- a/pigz.pdf
+++ b/pigz.pdf
Binary files differ
diff --git a/pigz.spec b/pigz.spec
index 4712abb..92d5e46 100644
--- a/pigz.spec
+++ b/pigz.spec
@@ -1,6 +1,6 @@
 Summary: pigz is a parallel implementation of gzip which utilizes multiple cores
 Name: pigz
-Version: 2.7
+Version: 2.8
 Release: 1
 Source0: %{name}-%{version}.tar.gz
 License: zlib
diff --git a/pigz.c b/pigz.c
index a771125..0e9d635 100644
--- a/pigz.c
+++ b/pigz.c
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
  * Copyright (C) 2007-2022 Mark Adler
  * Version 2.7  15 Jan 2022  Mark Adler
  */
 
 /*
@@ -205,9 +205,12 @@
                        Fix bug when combining -l with -d
                        Exit with status of zero if skipping non .gz files
                        Permit Huffman only (-H) when not compiling with zopfli
+   2.8    19 Aug 2023  Fix version bug when compiling with zlib 1.3
+                       Save a modification time only for regular files
+                       Write all available uncompressed data on an error
  */
 
-#define VERSION "pigz 2.7"
+#define VERSION "pigz 2.8"
 
 /* To-do:
     - make source portable for Windows, VMS, etc. (see gzip source code)
@@ -4478,7 +4481,7 @@
             case 'K':  g.form = 2;  g.sufx = ".zip";  break;
             case 'L':
                 puts(VERSION);
-                puts("Copyright (C) 2007-2022 Mark Adler");
+                puts("Copyright (C) 2007-2023 Mark Adler");
                 puts("Subject to the terms of the zlib license.");
                 puts("No warranty is provided or implied.");
                 exit(0);
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
- * Copyright (C) 2007-2022 Mark Adler
- * Version 2.7  15 Jan 2022  Mark Adler
+ * Copyright (C) 2007-2023 Mark Adler
+ * Version 2.8  19 Aug 2023  Mark Adler
  */
 